/*
    $File$
    Date        Author          Changes
    Nov 21 2000 Richard Jones   Created

    Copyright (c) 2000, Richard Jones
    All rights reserved.
 */

package MetaTF.Generator.Java;

import MetaTF.Parser.*;
import MetaTF.Panic;
import java.util.Map;
import MetaTF.Generator.Java.Util;

/**********************************************************************************************
 * ConstructorBodyGenerator.
 * Generate constructor body for each user-defined record.
 *
 * @see <a href="../../Parser/metatf.jjt">The MetaTF Grammar</a>
 * @version rel-1-2 ($Revision: 1.2 $, $Date: 2000/12/15 16:29:11 $),
 * @author Richard Jones
**/
class ConstructorBodyGenerator implements DTDVisitor {

    /** the number of the section being visited **/
    int currentSection = 0;

    /** The symbol table **/
    DTD symtab;
    
    ConstructorBodyGenerator(DTD st, int i) {
        symtab = st;
        currentSection = i;
    }
    
    public Object visit(NamedField field, Object knownFields) {        
        String name = Util.declassify(field.getName(), (Map)knownFields);
        String type = Util.typify(field.getType());
        return 
"        this."+name+" = "+name+";";
    }
    
    public Object visit(TagField field, Object knownFields) {        
        return null;
    }
    
    public Object visit(RepeatField field, Object knownFields) {
        return (String)field.getRepeat().accept(this, knownFields)+"\n"+
"        "+(String)field.getRepeatable().accept(this, knownFields);
    }
 
    public Object visit(TupleField field, Object knownFields) {
        try {
            String name = field.getName();
            String cname
                 = symtab.getSection(currentSection).getRecords().containsKey(name) ?
                       Util.classify(name) :
                       Util.classify(symtab.getSection(0).getName())+"."+Util.classify(name);
            String fname = Util.declassify(name, (Map)knownFields);
            return
"         this."+fname+" = "+fname+";";
        } catch (DTDException e) {
            // cannot happen
            Panic.panic(e.getMessage());
            return null;
        }
    }

        // NOT USED
	public Object visit(DTD symtab, Object data) {
        Panic.panic("ConstructorBodyGenerator finds DTD");
        return null;
    }    
	public Object visit(Section section, Object data) {
        Panic.panic("ConstructorBodyGenerator finds Section");
        return null;
    }    
	public Object visit(Record record, Object data) {
        Panic.panic("ConstructorBodyGenerator finds Record");
        return null;
    }    
	public Object visit(BaseOffset baseOffset, Object data) {
        Panic.panic("ConstructorBodyGenerator finds BaseOffset");
        return null;
    }    
	public Object visit(Default def, Object data) {
        Panic.panic("ConstructorBodyGenerator finds Default");
        return null;
    }    
	public Object visit(StringDefault def, Object data) {
        Panic.panic("ConstructorBodyGenerator finds StringDefault");
        return null;
    }    
	public Object visit(Delta delta, Object data) {
        Panic.panic("ConstructorBodyGenerator finds Delta");
        return null;
    }    
	public Object visit(None none, Object data) {
        Panic.panic("ConstructorBodyGenerator finds None");
        return null;
    }    
	public Object visit(NumberValue numberValue, Object data) {
        Panic.panic("ConstructorBodyGenerator finds NumberValue");
        return null;
    }    
	public Object visit(SectionStride sectionStride, Object data) {
        Panic.panic("ConstructorBodyGenerator finds SectionStride");
        return null;
    }    
	public Object visit(Stride stride, Object data) {
        Panic.panic("ConstructorBodyGenerator finds Stride");
        return null;
    }    
	public Object visit(SectionOffset value, Object data) {
        Panic.panic("ConstructorBodyGenerator finds SectionOffset");
        return null;
    }    

} // end of ConstructorBodyGenerator class

