/*
    $File$
    Date        Author          Changes
    Nov 30 2000 Richard Jones   Created
    
    Copyright (c) 2000, Richard Jones
    All rights reserved.
 */
 
package MetaTF.Runtime;

import MetaTF.BadRecordException;

/**
 * A TraceField representing a field.
 * For each record of each section, we construct an array of TraceFields,    
 * one for each named fields. This is essentially a flattening of the        
 * definition in the DTD of the record. As we read each field of the record, 
 * we consult this array for the width and encoding. The array is      
 * modified by metadata records.                                             
 *
 * @version rel-1-2 ($Revision: 1.2 $, $Date: 2001/03/29 15:53:24 $),
 * @author Richard Jones
**/                                        
public abstract class TraceField {                                                  
    /** The name of the named field **/                                      
    protected final String name;                                                

    /** The encoding of the named field **/                            
    protected int encodingType;                                           

    /** Allocate a new object representing the encoding of a named field **/  
    public TraceField(String n) { name = n; }                                

    /** Get the encodingType **/                                       
    public int getInterpretationType() { return encodingType; }
    
    /**
     * Set the encoding type of this field (none, default, ...)       
     * @param i the encoding                                           
     * @exception BadRecordException IF the encoding does not match the type of the field 
    **/                                                                      
    abstract void setInterpretationType(int i) throws BadRecordException;
    
    /**
     * Set the first encoding value                                   
     * @param i the value                                           
     * @exception BadRecordException IF the value is inappropriate for this type of field 
    **/
    abstract void setValue(long i) throws BadRecordException;
    
    /**
     * Set the first encoding value                                   
     * @param s the value (a string)                                         
     * @exception BadRecordException IF the value is inappropriate for this type of field 
    **/                                                                      
    abstract void setValue(String s) throws BadRecordException;
    
    /**
     * Set the second encoding value                                   
     * @param i the value                                           
     * @exception BadRecordException IF the value is inappropriate for this type of field 
    **/                                                                      
    abstract void setValue2(long i) throws BadRecordException;        
}                                                                            

